window.Gleam.initSearch([{"doc":"gleamyshell","title":"gleamyshell","content":"[![Package Version](https://img.shields.io/hexpm/v/gleamyshell)](https://hex.pm/packages/gleamyshell)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleamyshell)\n![Erlang-compatible](https://img.shields.io/badge/target-erlang-a2003e)\n![JavaScript-compatible](https://img.shields.io/badge/target-javascript-f1e05a)\n\n# GleamyShell 🐚\n\nGleamyShell is a cross-platform Gleam library for executing shell commands that supports all non-browser targets\n(Erlang, Bun, Deno, and Node.js).\n\n## When to use GleamyShell? 🐚\n\nGleamyShell provides the ability to execute shell commands on multiple targets. While this might sound amazing,\nsupporting targets with fundamentally different concurrency models and APIs shrinks the common ground significantly.\n\nIn order to keep the public API homogenous across different targets, GleamyShell only provides synchronous bindings and\na minimal API with common functionalities supported by those targets.\n\nYou should use GleamyShell if\n\n-   you need or want to support multiple targets _and/or_\n-   synchronous shell command execution is not a concern, _and most importantly_,\n-   you don&#39;t have special use cases that GleamyShell&#39;s API cannot serve\\*.\n\n\\* Feel free to [open an issue](https://github.com/patrik-kuehl/gleamyshell/issues) on GitHub to discuss your feature\nrequest. GleamyShell aims to implement features that can provide a similar, or ideally the same behavior on all\nsupported targets. Yours might be one of them.\n\nThe main workhorse of GleamyShell is its `execute` function. The remaining functions are quality-of-life features so\nusers of this library don&#39;t need to reach for further dependencies that often.\n\n## Usage 🐚\n\n### Getting the Current Username 🐚\n\n```gleam\ncase gleamyshell.execute(&quot;whoami&quot;, in: &quot;.&quot;, args: []) {\n  Ok(CommandOutput(0, username)) -&gt;\n    io.println(&quot;Hello there, &quot; &lt;&gt; string.trim(username) &lt;&gt; &quot;!&quot;)\n  Ok(CommandOutput(exit_code, output)) -&gt;\n    io.println(\n      &quot;Whoops!\\nError (&quot;\n      &lt;&gt; int.to_string(exit_code)\n      &lt;&gt; &quot;): &quot;\n      &lt;&gt; string.trim(output),\n    )\n  Error(reason) -&gt; io.println(&quot;Fatal: &quot; &lt;&gt; reason)\n}\n```\n\n### Getting the Current Working Directory 🐚\n\n```gleam\ncase gleamyshell.cwd() {\n  Ok(working_directory) -&gt;\n    io.println(&quot;Current working directory: &quot; &lt;&gt; working_directory)\n  Error(_) -&gt;\n    io.println(&quot;Couldn&#39;t detect the current working directory.&quot;)\n}\n```\n\n### Doing OS-specific Stuff 🐚\n\n```gleam\ncase gleamyshell.os() {\n  Windows -&gt; io.println(&quot;Doing stuff on Windows.&quot;)\n  Unix(Darwin) -&gt; io.println(&quot;Doing stuff on macOS.&quot;)\n  Unix(_) -&gt; io.println(&quot;Doing stuff on a Unix(-like) system.&quot;)\n}\n```\n\n## Upgrading to Version 2 🐚\n\nThe changelog covers the breaking changes, and the API documentation has been updated accordingly.\n\nIn a nutshell:\n\n-   `gleamyshell/set_env` and `gleamyshell/unset_env` have been removed due to the limitations of the APIs of Erlang and\n    Node.js (e.g., referenced variables couldn&#39;t be resolved as one might expect it to happen when using the shell\n    directly), so if you need to set and/or unset environment variables, do it in a platform-specific way within a\n    script file instead\n-   all functions, which returned an `Option` now return a `Result` to provide an API that is adhering to Gleam&#39;s\n    guidelines (thus becoming more idiomatic) to prefer `Result` over `Option` for failible functions\n-   `gleamyshell/execute` doesn&#39;t treat non-zero exit codes as errors any longer because for GleamyShell, a command that\n    could exit, no matter the exit code, did complete successfully\n\n## Changelog 🐚\n\nTake a look at the [changelog](https://github.com/patrik-kuehl/gleamyshell/blob/main/CHANGELOG.md) to get an overview of\neach release and its changes.\n\n## Contribution Guidelines 🐚\n\nMore information can be found [here](https://github.com/patrik-kuehl/gleamyshell/blob/main/CONTRIBUTING.md).\n\n## License 🐚\n\nGleamyShell is licensed under the [MIT license](https://github.com/patrik-kuehl/gleamyshell/blob/main/LICENSE.md).\n","url":"index.html"},{"doc":"gleamyshell","title":"gleamyshell","content":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/), and this project adheres to\n[Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [2.0.0] - 2024-07-12\n\n### Changed\n\n-   **(breaking)** `gleamyshell/execute` doesn&#39;t treat non-zero exit codes as errors any longer.\n-   **(breaking)** Made `gleamyshell/which` return a `Result` instead of an `Option`.\n-   **(breaking)** Made `gleamyshell/env` return a `Result` instead of an `Option`.\n-   **(breaking)** Made `gleamyshell/home_directory` return a `Result` instead of an `Option`.\n-   **(breaking)** Made `gleamyshell/cwd` return a `Result` instead of an `Option`.\n\n### Removed\n\n-   **(breaking)** Removed `gleamyshell/set_env` due to limitations of the APIs of Erlang and Node.js.\n-   **(breaking)** Removed `gleamyshell/unset_env`.\n\n## [1.1.0] - 2024-06-06\n\n### Added\n\n-   Introduced official support for [Bun](https://bun.sh/).\n\n## [1.0.0] - 2024-06-04\n\n### Added\n\n-   Added `gleamyshell/unset_env` to unset an environment variable.\n-   Added `gleamyshell/set_env` to set an environment variable.\n\n## [0.5.0] - 2024-06-01\n\n### Removed\n\n-   Removed Elixir as a dependency.\n-   **(breaking)** Removed `gleamyshell/execute_in` in favor of `gleamyshell/execute`.\n\n## [0.4.0] - 2024-05-31\n\n### Added\n\n-   Added `gleamyshell/env` to get the value of an environment variable.\n-   Added `gleamyshell/which` to get the path of an executable.\n\n## [0.3.1] - 2024-05-29\n\n### Fixed\n\n-   Made `gleamyshell/cwd_ffi` private again.\n\n## [0.3.0] - 2024-05-29\n\n### Added\n\n-   Added `gleamyshell/home_directory` to get the path of the user&#39;s home directory.\n\n### Fixed\n\n-   **(breaking)** `gleamyshell/cwd` now returns a consistent output across all supported targets.\n-   Removed the freezing of the standard library version. Discovered and fixed thanks to\n    [@darky](https://github.com/darky).\n\n## [0.2.0] - 2024-05-28\n\n### Added\n\n-   Added `gleamyshell/os` to get information about the operating system.\n-   **(breaking)** Defined the `gleamyshell/OsFamily` and `gleamyshell/Os` types, and renamed a constructor of the\n    `gleamyshell/AbortReason` type.\n\n## [0.1.0] - 2024-05-26\n\n### Added\n\n-   Added `gleamyshell/execute_in` to run a command in a specific working directory.\n-   Added `gleamyshell/cwd` to get the path of the current working directory.\n-   Added `gleamyshell/execute` to run a command.\n-   Defined the `gleamyshell/CommandError` and `gleamyshell/AbortReason` types.\n\n[unreleased]: https://github.com/patrik-kuehl/gleamyshell/compare/v2.0.0...HEAD\n[2.0.0]: https://github.com/patrik-kuehl/gleamyshell/compare/v1.1.0...v2.0.0\n[1.1.0]: https://github.com/patrik-kuehl/gleamyshell/compare/v1.0.0...v1.1.0\n[1.0.0]: https://github.com/patrik-kuehl/gleamyshell/compare/v0.5.0...v1.0.0\n[0.5.0]: https://github.com/patrik-kuehl/gleamyshell/compare/v0.4.0...v0.5.0\n[0.4.0]: https://github.com/patrik-kuehl/gleamyshell/compare/v0.3.1...v0.4.0\n[0.3.1]: https://github.com/patrik-kuehl/gleamyshell/compare/v0.3.0...v0.3.1\n[0.3.0]: https://github.com/patrik-kuehl/gleamyshell/compare/v0.2.0...v0.3.0\n[0.2.0]: https://github.com/patrik-kuehl/gleamyshell/compare/v0.1.0...v0.2.0\n[0.1.0]: https://github.com/patrik-kuehl/gleamyshell/releases/tag/v0.1.0\n","url":"changelog.html"},{"doc":"gleamyshell","title":"gleamyshell","content":"# MIT License\n\nCopyright (c) 2024 Patrik Kühl\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated\ndocumentation files (the &quot;Software&quot;), to deal in the Software without restriction, including without limitation the\nrights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit\npersons to whom the Software is furnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all copies or substantial portions of the\nSoftware.\n\nTHE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE\nWARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR\nCOPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR\nOTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.\n","url":"license.html"},{"doc":"gleamyshell","title":"CommandOutput","content":"pub type CommandOutput {\n  CommandOutput(exit_code: Int, output: String)\n}\n Represents information about the exit code and output of the\n executed command.\n \n `output` equals the output stream (stdout) when the command\n exited with an exit code of one, otherwise it equals the\n error stream (stderr).\nCommandOutput(exit_code: Int, output: String)\n\n\nSynonyms:\ngleamyshell.CommandOutput\ngleamyshell CommandOutput","url":"gleamyshell.html#CommandOutput"},{"doc":"gleamyshell","title":"Os","content":"pub type Os {\n  Darwin\n  FreeBsd\n  OpenBsd\n  Linux\n  SunOs\n  OtherOs(String)\n}\n Represents names of operating systems.\nDarwin\n The Unix operating system used by Apple as a core for its\n operating systems (e.g., macOS).\n\nFreeBsd\n A free Unix-like operating system descended from AT&amp;T&#39;s UNIX.\n\nOpenBsd\n A free Unix-like operating system forked from NetBSD.\n\nLinux\n The Linux kernel is the base for many Unix-like operating\n systems like Debian.\n\nSunOs\n The Unix-like operating system SunOS is used as a core for\n other distributions like Solaris.\n\nOtherOs(String)\n An operating system not represented by the other options.\n\nSynonyms:\ngleamyshell.Os\ngleamyshell Os","url":"gleamyshell.html#Os"},{"doc":"gleamyshell","title":"OsFamily","content":"pub type OsFamily {\n  Unix(Os)\n  Windows\n}\n Represents families of operating systems.\nUnix(Os)\n The operating system is part of the Unix family.\n\nWindows\n The operating system is part of the Windows family.\n\nSynonyms:\ngleamyshell.OsFamily\ngleamyshell OsFamily","url":"gleamyshell.html#OsFamily"},{"doc":"gleamyshell","title":"cwd","content":"pub fn cwd() -&gt; Result(String, Nil)\n Returns the current working directory.\n \n ## Example\n \n \n case gleamyshell.cwd() {\n   Ok(working_directory) -&gt;\n     io.println(&quot;Current working directory: &quot; &lt;&gt; working_directory)\n   Error(_) -&gt; io.println(&quot;Couldn&#39;t detect the current working directory.&quot;)\n }\n \nSynonyms:\ngleamyshell.cwd\ngleamyshell cwd","url":"gleamyshell.html#cwd"},{"doc":"gleamyshell","title":"env","content":"pub fn env(identifier: String) -&gt; Result(String, Nil)\n Returns the value of the given environment variable if it is set.\n \n ## Example\n \n \n case gleamyshell.env(&quot;JAVA_HOME&quot;) {\n   Ok(dir) -&gt; io.println(&quot;Java runtime location: &quot; &lt;&gt; dir)\n   Error(_) -&gt; \n     io.println(&quot;The location of the Java runtime could not be found.&quot;)\n }\n \nSynonyms:\ngleamyshell.env\ngleamyshell env","url":"gleamyshell.html#env"},{"doc":"gleamyshell","title":"execute","content":"pub fn execute(\n  executable: String,\n  in working_directory: String,\n  args args: List(String),\n) -&gt; Result(CommandOutput, String)\n Executes the given command with arguments.\n\n ## Example\n \n \n case gleamyshell.execute(&quot;whoami&quot;, in: &quot;.&quot;, args: []) {\n   Ok(CommandOutput(0, username)) -&gt;\n     io.println(&quot;Hello there, &quot; &lt;&gt; string.trim(username) &lt;&gt; &quot;!&quot;)\n   Ok(CommandOutput(exit_code, output)) -&gt;\n     io.println(\n       &quot;Whoops!\\nError (&quot;\n       &lt;&gt; int.to_string(exit_code)\n       &lt;&gt; &quot;): &quot;\n       &lt;&gt; string.trim(output),\n     )\n   Error(reason) -&gt; io.println(&quot;Fatal: &quot; &lt;&gt; reason)\n }\n \nSynonyms:\ngleamyshell.execute\ngleamyshell execute","url":"gleamyshell.html#execute"},{"doc":"gleamyshell","title":"home_directory","content":"pub fn home_directory() -&gt; Result(String, Nil)\n Returns the home directory of the current user.\n \n This function returns an `Option` because it can fail in rare circumstances.\n \n ## Example\n \n \n case gleamyshell.home_directory() {\n   Ok(home_directory) -&gt; io.println(&quot;Home directory: &quot; &lt;&gt; home_directory)\n   Error(_) -&gt;\n     io.println(&quot;Couldn&#39;t detect the home directory of the current user.&quot;)\n }\n \nSynonyms:\ngleamyshell.home_directory\ngleamyshell home_directory","url":"gleamyshell.html#home_directory"},{"doc":"gleamyshell","title":"os","content":"pub fn os() -&gt; OsFamily\n Returns information about the host&#39;s operating system.\n \n ## Example\n \n \n case gleamyshell.os() {\n   Windows -&gt; io.println(&quot;Doing stuff on Windows.&quot;)\n   Unix(_) -&gt; io.println(&quot;Doing stuff on a Unix(-like) system.&quot;)\n }\n \nSynonyms:\ngleamyshell.os\ngleamyshell os","url":"gleamyshell.html#os"},{"doc":"gleamyshell","title":"which","content":"pub fn which(executable: String) -&gt; Result(String, Nil)\n Returns the location of the given executable if it could be found.\n \n ## Example\n \n \n case gleamyshell.which(&quot;git&quot;) {\n   Ok(_) -&gt; io.println(&quot;Doing something with Git.&quot;)\n   Error(_) -&gt; io.println(&quot;Git could not be found.&quot;)\n }\n \nSynonyms:\ngleamyshell.which\ngleamyshell which","url":"gleamyshell.html#which"},{"doc":"gleamyshell","title":"gleamyshell","content":"","url":"gleamyshell.html"}]);